@@ -4,7 +4,6 @@ use strict;
 use warnings;
 use Data::Dumper;
 use File::Temp;
-use File::Copy qw(copy);
 use File::Path qw(make_path);
 use Cwd;
 use Expect;
@@ -16,11 +15,11 @@ RPM::Packager - Manifest-based approach for building RPMs
 
 =head1 VERSION
 
-Version 0.2.0
+Version 0.2.1
 
 =cut
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
 =head1 SYNOPSIS
 
@@ -90,9 +89,11 @@ Constructor.  Pass in a hash containing manifest info.
 sub new {
     my ( $class, %args ) = @_;
     chomp( my $fpm = `which fpm 2>/dev/null` );
+    chomp( my $cp  = `which cp` );
 
     my $self = {
         fpm     => $fpm,
+        cp      => $cp,
         cwd     => getcwd(),
         tempdir => File::Temp->newdir(),
         %args
@@ -131,14 +132,10 @@ sub copy_to_tempdir {
     my $tempdir = $self->{tempdir};
 
     for my $key ( keys %hash ) {
-        my @files      = RPM::Packager::Utils::find_files("$cwd/$key");
         my $dst        = $hash{$key};
         my $target_dir = "$tempdir$dst";
         make_path($target_dir);
-
-        for my $file (@files) {
-            copy $file, $target_dir;
-        }
+        system("$self->{cp} -r $cwd/$key/* $target_dir");
     }
     return 1;
 }
